
Changelog
=========

1.0.0 (2021-04-08)
------------------

* Added support for Python 3.
  Contributed by Emil Stenström in `#5 <https://github.com/ionelmc/pypi-alias/pull/5>`_.
* Dropped support for Python 2.
* Switched to argparse and added the ``--version`` and ``--dirty`` arguments.
* Added some light CI/testing.

0.2.0 (2015-06-18)
------------------

* Fix regression in ``__main__``.

0.1.0 (2015-06-18)
------------------

* First release on PyPI.
